#!/bin/bash
# Copyright 2020 Cohesity Inc.
#
# Author Vivek Velankar
#
# Note: common.sql takes 3rd arguement for 'task_id'. Since 'task_id' is not
# needed for querying progress, that argument is sent as "dummy".
#
# In the below query we return one row only containing the number of datafile
# and redolog bytes still hosted on the MOUNT_PATH and total bytes for the
# datafiles and redologs.
# Using this we calculate the migration work remaining.
# This script is invoked using sql_shell.sh script.

set -e

export COMMON_PATH=$7
export MOUNT_PATH=$5
export CONNECT_STRING=$2

$1 -S <<EOF
$CONNECT_STRING
@$COMMON_PATH/common.sql $3 $4 "dummy" $6;

SELECT /*+ RULE*/
(SELECT /*+ RULE*/
  SUM(
    (SELECT /*+ RULE*/ COALESCE(NULLIF(SUM(BYTES), 0), 0) from V\$datafile) +
    (SELECT /*+ RULE*/ COALESCE(NULLIF(SUM(BYTES * MEMBERS), 0), 0) from V\$log)
  )
from dual) total_bytes_to_migrate,
(SELECT /*+ RULE*/
  SUM(
    (SELECT /*+ RULE*/ COALESCE(NULLIF(SUM(BYTES), 0), 0) from V\$datafile where name like '%$MOUNT_PATH%') +
    (SELECT /*+ RULE*/ COALESCE(NULLIF(SUM(R.BYTES), 0), 0) FROM V\$log R JOIN v\$logfile L ON L.Group#=R.Group# where L.MEMBER like '%$MOUNT_PATH%')
  )
from dual) bytes_remaining_to_migrate
from dual;
exit;
EOF
