#!/bin/bash
#
# Copyright 2019 Cohesity Inc.
#
# Author : Mahesh K
#
# Plug a given PDB to a cdb.
# Has methods to drop database if exists.
# Heredoc approach is used as the FileNameConvert can exceed the sql
# 240 character limit.
#
# This script is invoked using sql_shell.sh script.

set -e

export COMMON_PATH=$7
export PDB_NAME=$8
export XML_LOC=$9
export FILE_NAME_CONVERT=${10}
export CONNECT_STRING=$2
export DROP_PDB=${11}

# Check if valid XMl location is provided.
if [ ! -f ${XML_LOC} ]; then
  echo "Invalid xml location provided: ${XML_LOC}"
  exit 1
fi

# Check if we want to drop the pdb.
if [[ -z ${DROP_PDB} ]]; then
  DROP_PDB=0
fi

# Approach.
# If the user chooses to drop the db, then drop the db if exists.
# Then clone the pdb from the xml to the destination cdb.
# TODO(Mahesh): Handle the case for plug violations, either run data patch or
# inform the user about possible plug violations.
$1 -S <<EOF
$CONNECT_STRING
@$COMMON_PATH/common.sql $3 $4 "dummy" $6;

BEGIN
  if $DROP_PDB = 1 THEN
    EXECUTE IMMEDIATE 'DROP PLUGGABLE DATABASE $PDB_NAME INCLUDING DATAFILES';
  END IF;
  EXCEPTION
    WHEN OTHERS THEN
      IF SQLCODE != '-65011' THEN
        RAISE;
      END IF;
  END;
/
CREATE PLUGGABLE DATABASE $PDB_NAME as CLONE USING '$XML_LOC' COPY file_name_convert=($FILE_NAME_CONVERT);
quit;
EOF

#ignore error on opening pdb on all instances
set +e

$1 -S <<EOF
$CONNECT_STRING
ALTER PLUGGABLE DATABASE ${PDB_NAME} OPEN INSTANCES = ALL;
EOF

result=$?

if [ $result -ne 0]; then
  echo "Failed to open pdb: ${PDB_NAME} on all instances."
else
  echo "Successfully opened pdb: ${PDB_NAME} on all instances."
fi
